"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const tasks_1 = require("@angular-devkit/schematics/tasks");
const devDependencies = [
    {
        name: 'wallaby-webpack',
        version: '*'
    },
    {
        name: 'angular2-template-loader',
        version: '^0.6.2'
    }
];
function ngAdd(_options) {
    return schematics_1.chain([
        addConfigFile(),
        addBootstrapFile(),
        modifyTsconfigExcludeFile(),
        addLoadersToPackageJson(),
        addPackageInstallTask()
    ]);
}
exports.default = ngAdd;
function addConfigFile() {
    return (tree, context) => {
        const wallabyConfigFileName = 'wallaby.js';
        const files = schematics_1.url(`../../files`)(context);
        const scriptContent = files.read(wallabyConfigFileName).toString('utf-8');
        if (!tree.exists(wallabyConfigFileName)) {
            tree.create(wallabyConfigFileName, scriptContent);
        }
    };
}
function addBootstrapFile() {
    return (tree, context) => {
        const wallabyBootstrapFileName = 'src/wallabyTest.ts';
        const files = schematics_1.url(`../../files`)(context);
        const scriptContent = files
            .read(wallabyBootstrapFileName)
            .toString('utf-8');
        if (!tree.exists(wallabyBootstrapFileName)) {
            tree.create(wallabyBootstrapFileName, scriptContent);
        }
    };
}
function modifyTsconfigExcludeFile() {
    return (tree) => {
        const tsConfigSource = tree
            .read('src/tsconfig.app.json')
            .toString('utf-8');
        const json = JSON.parse(tsConfigSource);
        if (json['exclude']) {
            if (!json['exclude'].includes('wallabyTest.ts')) {
                json['exclude'].push('wallabyTest.ts');
            }
        }
        tree.overwrite('src/tsconfig.app.json', JSON.stringify(json, null, 2));
    };
}
function addLoadersToPackageJson() {
    return (tree) => {
        devDependencies.forEach(dependency => {
            addDependencyToPackageJson(tree, 'devDependencies', dependency.name, dependency.version);
        });
        return tree;
    };
}
function addPackageInstallTask() {
    return (tree, context) => {
        const depNames = devDependencies.map(d => d.name).join(' ');
        context.addTask(new tasks_1.NodePackageInstallTask({
            packageName: depNames
        }));
        return tree;
    };
}
/**
 * Adds a package to the package.json
 */
function addDependencyToPackageJson(tree, type, pkg, version = 'latest') {
    if (tree.exists('package.json')) {
        const sourceText = tree.read('package.json').toString('utf-8');
        const json = JSON.parse(sourceText);
        if (!json[type]) {
            json[type] = {};
        }
        if (!json[type][pkg]) {
            json[type][pkg] = version;
        }
        tree.overwrite('package.json', JSON.stringify(json, null, 2));
    }
    return tree;
}
exports.addDependencyToPackageJson = addDependencyToPackageJson;
//# sourceMappingURL=index.js.map